//****************************************************************************
// FileName : WDLIB.H
// Function : WDT Function Define of Include File
// Design's : By Damon
// BuildDate: 01/28/2013 V1.0
//****************************************************************************
#ifndef __WDLIB_H
#define __WDLIB_H

#ifndef __DOS_H
  #include <dos.h>
#endif

//Default value define as follows:
#define WdUnitS 0x80 //watch dog counter value of unit is second
#define WdUnitM 0x00 //watch dog counter value of unit is minute
#define WDTRESET 0x0C      //RESET signal
#define WDTIRQ 0x08      //IRQ15 signal

#ifdef __cplusplus
extern "C" {
#endif

//==========================================================================//
// INITWDT                                                                                                                                                         //
//==========================================================================//
//Function:Initial Watch-Dog
//Input: 	SetWdtTriggerType=> 	Select the Watch-Dog Timeout Event.
//				0x80: Generate an interrupt when the WDT time-out.
//				0x0C: Reset system when the WDT time-out.
//          	SetWdtTimeUnit=>		Set the Watch-Dog timer unit.
//				0x00:Minutes
//				0x01:Sceonds
//	SetWdtIRQMap=>		Watch-Dog interrupt mapping, this parameter is valid when
//				the Watch-Dog Timeout Event is set to generate an interrupt.
//				0xF0:IRQ15
//				        :
//				0x30:IRQ3
//				0x20:IRQ2
//				0x10:IRQ1
//				0x00:Disable
//Return:	None
//========================================================================//
void INITWDT(char SetWdtTriggerType,char SetWdtTimeUnit,char SetWdtIRQMap);

//=========================================================================//
// ENWDT                                                                                                                                                          //
//=========================================================================//
// Function : Enable Watch-Dog                                                                                                              //
// Input       : WdtValue=>	The Watch-dog Timer Time-out Value     
//			00  Time-out disable
//			01  time-out = 1 minutes (second)
//			KK.
//			FF  time-out = 255 minutes (second)
//
// Return     :NONE                                                                                                                                            
//==========================================================================//
void ENWDT(char WdtValue);

//==========================================================================//
// DISWDT                                                                                                                                                           //
//==========================================================================//
// Function : Disable Watch-Dog                                                                                                               //     
// Input        : NONE                                     																					                //
// Return     : NONE                                                                                                                                          //
//==========================================================================//
void DISWDT();



#ifdef __cplusplus
}
#endif

#endif  // __WDLIB_H
